Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(722)

Unified Diff: components/cronet/android/cronet_url_request_context_adapter.h

Issue 1079163007: net_log_logger_ replaced with write_to_file_observer_ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: net_log_logger_ replaced with write_to_file_observer_ Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/cronet/android/cronet_url_request_context_adapter.h
diff --git a/components/cronet/android/cronet_url_request_context_adapter.h b/components/cronet/android/cronet_url_request_context_adapter.h
index d20c02fc861a8f8f58c165b65b930b461350fc98..fea2454d2eaf0368b8e1beb1b5907edd3382d173 100644
--- a/components/cronet/android/cronet_url_request_context_adapter.h
+++ b/components/cronet/android/cronet_url_request_context_adapter.h
@@ -86,8 +86,9 @@ class CronetURLRequestContextAdapter {
// Network thread is owned by |this|, but is destroyed from java thread.
base::Thread* network_thread_;
- // |net_log_logger_| and |context_| should only be accessed on network thread.
- scoped_ptr<net::WriteToFileNetLogObserver> net_log_logger_;
+ // |write_to_file_observer_| and |context_| should only be accessed on
+ // network thread.
+ scoped_ptr<net::WriteToFileNetLogObserver> write_to_file_observer_;
scoped_ptr<net::URLRequestContext> context_;
scoped_ptr<net::ProxyConfigService> proxy_config_service_;
« no previous file with comments | « chrome/browser/net/net_log_temp_file.cc ('k') | components/cronet/android/cronet_url_request_context_adapter.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698